
import re
import operator

from django.apps import apps
from django.conf import settings
from django.db.models import Q

try:
    from functools import reduce
except ImportError:
    pass


TERMS = re.compile(r'"([^"]+)"|(\S+)').findall
NORM_SPACE = re.compile(r'\s{2,}').sub


def normalize_query(query_string, terms=TERMS, norm_space=NORM_SPACE):
    """
    Example:
    >>> normalize_query('  some random  words "with   quotes  " and   spaces')
    ['some', 'random', 'words', 'with quotes', 'and', 'spaces']
    """
    return [
        norm_space(' ', (t[0] or t[1]).strip()) for t in terms(query_string)]


def build_query(query_string, search_fields):

    terms = normalize_query(query_string)

    if not terms:
        return None

    query = reduce(
        operator.__and__,
        (reduce(
            operator.__or__,
            (Q(**{"%s__icontains" % field_name: term})
             for field_name in search_fields)
        ) for term in terms),
    )
    return query


def model_search(query, queryset, fields):

    assert query is not None

    entry_query = build_query(query, fields)

    return queryset.filter(entry_query)


def tags_search(query, queryset, fields):

    tag_fields = ['text_%s' % code for code in dict(settings.LANGUAGES).keys()]

    search_tag_model = apps.get_model('model_search', 'SearchTag')

    tags = model_search(query, search_tag_model.objects.all(), tag_fields)

    return queryset.filter(Q(tags__in=tags) | build_query(query, fields))



# Generated by Django 2.0.9 on 2019-07-14 16:18

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Review',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.BooleanField(default=False, verbose_name='Is active')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('rating', models.PositiveIntegerField(choices=[(1, '1'), (2, '2'), (3, '3'), (4, '4'), (5, '5')], default=5, verbose_name='Rating')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date created')),
                ('text', models.TextField(max_length=1000, verbose_name='Review')),
                ('photo', models.FileField(blank=True, null=True, upload_to='reviews', verbose_name='Photo')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='reviews', to=settings.AUTH_USER_MODEL, verbose_name='Owner')),
            ],
            options={
                'verbose_name': 'Review',
                'verbose_name_plural': 'Reviews',
                'ordering': ('-id',),
            },
        ),
    ]




from django.test import TestCase
from django.core.management import call_command


from model_search import normalize_query


class SearchTestCase(TestCase):

    def setUp(self):
        call_command('sync_translation_fields', interactive=False)

    def test_normalize_query_returns_words_list(self):

        query = '  some random  words "with   quotes  " and   spaces'

        result = ['some', 'random', 'words', 'with quotes', 'and', 'spaces']

        self.assertEqual(normalize_query(query), result)




from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _


class Review(models.Model):

    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, related_name='reviews',
        verbose_name=_('Owner'), null=True, blank=True,
        on_delete=models.SET_NULL)

    is_active = models.BooleanField(_('Is active'), default=False)

    name = models.CharField(_("Name"), max_length=255)

    rating = models.PositiveIntegerField(
        _('Rating'), default=5, choices=((x, str(x)) for x in range(1, 6)))

    date_created = models.DateTimeField(
        _('Date created'), auto_now_add=True, editable=False)

    text = models.TextField(_('Review'), max_length=1000, blank=False)

    photo = models.FileField(
        _('Photo'), blank=True, null=True, upload_to='reviews')

    def __str__(self):
        return self.name

    class Meta:
        ordering = ('-id', )
        verbose_name = _('Review')
        verbose_name_plural = _('Reviews')




from turbosms import defaults


class TurboSMSSettings(object):

    IS_SMS_ENABLED = defaults.IS_SMS_ENABLED
    SMS_RECIPIENTS = defaults.SMS_RECIPIENTS
    SMS_SIGNATURE = defaults.SMS_SIGNATURE
    SMS_USERNAME = ''
    SMS_PASSWORD = ''

    @property
    def INSTALLED_APPS(self):
        return super().INSTALLED_APPS + [
            'turbosms'
        ]

    @property
    def DATABASES(self):
        databases = super().DATABASES

        if self.IS_SMS_ENABLED:
            databases['turbosms'] = {
                'ENGINE': 'django.db.backends.mysql',
                'NAME': 'users',
                'USER': self.SMS_USERNAME,
                'PASSWORD': self.SMS_PASSWORD,
                'HOST': '94.249.146.189',
                'PORT': ''
            }

        return databases

    @property
    def DATABASE_ROUTERS(self):
        return super().DATABASE_ROUTERS + [
            'turbosms.routers.TurboSMSRouter'
        ]


default = TurboSMSSettings





class SeoAppSettings(object):

    @property
    def MIDDLEWARE(self):
        return super().MIDDLEWARE + [
            'seo.middleware.PageMetaMiddleware'
        ]

    @property
    def INSTALLED_APPS(self):
        return super().INSTALLED_APPS + [
            'sitemetrics',
            'seo'
        ]

default = SeoAppSettings




from django.db import models
from django.template import Template
from django.utils.translation import ugettext_lazy as _
from django.utils.safestring import mark_safe


class PageMeta(models.Model):

    META_ROBOTS_CHOICES = (
        ('index, follow', _('Index, Follow')),
        ('noindex, nofollow', _('No Index, No Follow')),
        ('index, nofollow', _('Index, No Follow')),
        ('noindex, follow', _('No Index, Follow')),
    )

    FIELDS_FOR_RENDERING = {
        'title', 'keywords', 'description', 'breadcrumb', 'header'}

    url = models.CharField(
        _('URL'), max_length=255, blank=False, unique=True, db_index=True)

    title = models.CharField(_('Title'), max_length=68, blank=False)

    keywords = models.CharField(_('Keywords'), max_length=100, blank=True)

    description = models.CharField(
        _('Description'), max_length=155, blank=True)

    breadcrumb = models.CharField(_('Breadcrumb'), max_length=100, blank=True)

    header = models.CharField(_('Header'), max_length=100, blank=True)

    og_image = models.CharField(_('og:image'), max_length=500, blank=True)

    robots = models.CharField(
        _('Robots'), max_length=30, blank=True, default='index, follow',
        choices=META_ROBOTS_CHOICES)

    def render(self, field_name, context, default=''):

        if field_name == 'charset':
            return mark_safe('<meta charset="utf-8">')

        if field_name == 'robots':
            return self._render_meta_tag(field_name, self.robots)

        if field_name == 'og:image':
            return self.render_og_image_tag(context, default)

        if field_name not in self.FIELDS_FOR_RENDERING:
            raise ValueError

        value = getattr(self, field_name)

        if not value:
            return default

        value = self._render_value(value, context)

        if field_name in ['keywords', 'description']:
            return self._render_meta_tag(field_name, value)

        return value

    def render_og_image_tag(self, context, default):

        if self.og_image:
            og_image = self._render_value(self.og_image, context)
        else:
            og_image = default

        try:
            return mark_safe(
                """
                    <meta property="og:image" 
                          content="https://{}{}">
                """.format(
                    context.request.META['HTTP_HOST'],
                    og_image
                )
            )
        except Exception as e:
            print(e)
            return ''

    def _render_value(self, value, context):
        return Template(value).render(context)

    def _render_meta_tag(self, field_name, value):
        return mark_safe(
            '<meta name="{}" content="{}">'.format(field_name, value)
        )

    def __str__(self):
        return '{} - {}'.format(self.url, self.title)

    class Meta:
        verbose_name = _('Page meta')
        verbose_name_plural = _('Pages meta')


class RedirectRecord(models.Model):

    old_path = models.CharField(
        _('Old path'), max_length=1024, db_index=True, unique=True)

    new_path = models.CharField(_('New path'), max_length=1024)

    def __str__(self):
        return self.old_path

    class Meta:
        verbose_name = _('Redirect record')
        verbose_name_plural = _('Redirect records')


class ErrorRecord(models.Model):

    path = models.CharField(_('Path'), max_length=1024, db_index=True)

    referrer = models.CharField(_('Referrer'), max_length=1024, blank=True)

    status_code = models.IntegerField(_('Status code'))

    created = models.DateTimeField(_('Creation date'), auto_now_add=True)

    method = models.CharField(_('Method'), max_length=100)

    def __str__(self):
        return '[{}] {}'.format(str(self.status_code).upper(), self.path)

    @classmethod
    def create(cls, request, status_code):
        return cls.objects.create(
            path=request.get_full_path(),
            status_code=status_code,
            method=request.method,
            referrer=request.META.get('HTTP_REFERER', ''))

    class Meta:
        verbose_name = _('Error record')
        verbose_name_plural = _('Error records')


class SearchQuery(models.Model):

    query = models.CharField(
        _('Query'), max_length=255, blank=True)

    result_count = models.IntegerField(
        _('Result count'))

    filter_options = models.TextField(
        _('Filter options'), max_length=2000, blank=True)

    created = models.DateTimeField(
        _('Created'), auto_now_add=True)

    def __str__(self):
        return str(self.created)

    class Meta:
        verbose_name = _('Search query')
        verbose_name_plural = _('Search queries')



# -*- coding: utf-8 -

page_meta = [
    {
        'url': 'reviews:list',
        'title': 'Відгуки',
        'title_uk': 'Відгуки',
        'title_ru': 'Отзывы',
        'title_en': 'Reviews',
        'keywords': 'Відгуки',
        'keywords_uk': 'Відгуки',
        'keywords_ru': 'Отзывы',
        'keywords_en': 'Reviews',
        'description': 'Відгуки на сайті',
        'description_uk': 'Відгуки на сайті',
        'description_ru': 'Отзывы на сайте',
        'description_en': 'Reviews on site',
        'breadcrumb': 'Відгуки',
        'breadcrumb_uk': 'Відгуки',
        'breadcrumb_ru': 'Отзывы',
        'breadcrumb_en': 'Reviews',
        'header': 'Відгуки',
        'header_uk': 'Відгуки',
        'header_ru': 'Отзывы',
        'header_en': 'Reviews'
    }
]




from pydoc import locate

from django.conf import settings
from django.core.management.base import BaseCommand

from modeltranslation.utils import get_translation_fields

from seo.models import PageMeta


class Command(BaseCommand):

    def handle(self, *args, **options):

        for app_name in settings.INSTALLED_APPS:
            self._create_page_meta(app_name)

        self.stdout.write(self.style.SUCCESS('Success'))

    def _create_page_meta(self, app_name):

        meta_list = locate(app_name + '.seo.page_meta')

        if not meta_list:
            return

        for params in meta_list:

            if PageMeta.objects.filter(url=params['url']).exists():
                continue

            record = PageMeta(url=params['url'])

            for f_name in PageMeta.FIELDS_FOR_RENDERING:

                if f_name in params:
                    setattr(record, f_name, params[f_name])

                for trans_field in get_translation_fields(f_name):
                    if trans_field in params:
                        setattr(record, trans_field, params[trans_field])

            record.save()




from django import template
from cap.config import get_config


register = template.Library()


@register.simple_tag(takes_context=True)
def cap_form_conf(context, param_name, inline_admin_formset=None):
    """
    Get form config param
    """
    if inline_admin_formset:
        model_admin = inline_admin_formset.opts
    else:
        model_admin = context['adminform'].model_admin
    param_by_model_admin = getattr(model_admin, 'cap_%s' % param_name, None)
    if param_by_model_admin is not None:
        return param_by_model_admin
    return get_config(param_name, context['request'])




from django.apps import apps
from django import template


register = template.Library()


@register.simple_tag
def get_latest_reviews():
    Review = apps.get_model('reviews', 'Review')
    return Review.objects.filter(is_active=True).order_by('-id')[:5]




from django.urls import path, include
from django.conf.urls.i18n import i18n_patterns

from reviews import views


app_name = 'reviews'


urlpatterns = [

    path('', views.ReviewListView.as_view(), name='list'),

    path('api/', views.ReviewAPI.as_view(), name='api')

]

app_urls = i18n_patterns(

    path('reviews/', include((urlpatterns, app_name)))

)




from modeltranslation.translator import translator, TranslationOptions

from model_search.models import SearchTag


class SearchTagTranslationOptions(TranslationOptions):
    fields = ('text', )


translator.register(SearchTag, SearchTagTranslationOptions)




from django.contrib import admin

from reviews.models import Review


@admin.register(Review)
class ReviewAdmin(admin.ModelAdmin):

    list_filter = ['is_active']

    list_display = ['name', 'date_created', 'user', 'rating', 'is_active']

    list_editable = ['is_active']

    search_fields = ['id', 'name', 'text']

    fields = (
        ('is_active', 'user', ),
        ('name', 'rating', ),
        ('photo', ),
        'text',
    )




from django.urls import path, include
from django.conf.urls.i18n import i18n_patterns

from callback.views import CreateCallbackView


app_name = 'callback'


urlpatterns = [

    path('', CreateCallbackView.as_view(), name='modal')

]

app_urls = i18n_patterns(

    path('callback/', include((urlpatterns, app_name)))

)




import os

from imagekit.processors import ResizeToFit
from imagekit.lib import Image, ImageEnhance

from django.conf import settings


WATERMARKS = getattr(settings, 'WATERMARKS', {})


def _get_coordinates(position_x, position_y, img_size, wm_size):

    sh, sv = position_x, position_y

    if isinstance(sh, str) and '%' in sh:
        sh = int(img_size[0] * float(sh.rstrip("%")) / 100)

    if isinstance(sh, int) and sh < 0:
        sh = img_size[0] - wm_size[0] + sh

    if sh == 'left':
        sh = 0
    elif sh == 'center':
        sh = (img_size[0] - wm_size[0]) / 2
    elif sh == 'right':
        sh = img_size[0] - wm_size[0]

    if isinstance(sv, str) and '%' in sv:
        sv = int(img_size[1] * float(sv.rstrip("%")) / 100)

    if isinstance(sv, int) and sv < 0:
        sv = img_size[1] - wm_size[1] + sv

    if sv == 'top':
        sv = 0
    elif sv == 'center':
        sv = (img_size[1] - wm_size[1]) / 2
    elif sv == 'bottom':
        sv = img_size[1] - wm_size[1]

    return int(sh), int(sv)


def insert_watermark(key, img_path):

    try:
        params = WATERMARKS[key]
    except KeyError:
        pass

    src_img = Image.open(img_path)

    wm = Image.open(os.path.join(settings.STATIC_ROOT, params['file']))
    wm_size = list(wm.size)

    if params.get('scale'):
        wm = ResizeToFit(src_img.size[0], src_img.size[1], True).process(wm)
        wm_size = wm.size

    layer = Image.new('RGBA', src_img.size, (0, 0, 0, 0))

    coordinates = _get_coordinates(
        params['position_x'],
        params['position_y'],
        src_img.size,
        wm_size
    )

    if params.get('repeat'):
        sx = coordinates[0] % wm_size[0] - wm_size[0]
        sy = coordinates[1] % wm_size[1] - wm_size[1]
        for x in range(sx, src_img.size[0], wm_size[0]):
            for y in range(sy, src_img.size[1], wm_size[1]):
                layer.paste(wm, (x, y))
    else:
        layer.paste(wm, coordinates)

    opacity = params.get('opacity', 1)

    if opacity < 1:
        alpha = layer.split()[3]
        alpha = ImageEnhance.Brightness(alpha).enhance(opacity)
        layer.putalpha(alpha)

    dst_img = Image.composite(layer, src_img, layer)

    os.remove(img_path)

    dst_img.save(img_path)




from django.apps import apps
from django.contrib import admin

from ckeditor_uploader.widgets import CKEditorUploadingWidget

from site_config.models import ConfigField, HTMLField
from site_config import config


def _get_parent_admin_classes():

    if apps.is_installed('modeltranslation'):
        from modeltranslation.admin import TranslationAdmin
        classes = [TranslationAdmin]
    else:
        classes = [admin.ModelAdmin]

    if apps.is_installed('import_export'):

        from import_export.resources import ModelResource
        from import_export.admin import ImportExportMixin, ExportActionMixin

        class ConfigFieldResource(ModelResource):
            class Meta:
                model = ConfigField
                exclude = ('id', )

        class ImportExportAdmin(
                ImportExportMixin,
                ExportActionMixin):

            actions_on_bottom = False
            resource_class = ConfigFieldResource

        classes.append(ImportExportAdmin)

    return classes


@admin.register(ConfigField)
class ConfigFieldAdmin(*_get_parent_admin_classes()):

    CONFIG_FIELDS = ['label', 'name', 'type', 'splitter']

    list_display = [
        'label', 'name', 'type', 'splitter', 'short_value']

    list_per_page = 200


    def save_model(self, *args, **kwargs):
        super(ConfigFieldAdmin, self).save_model(*args, **kwargs)
        config.reload()

    class Meta:
        formfield_overrides = {
            HTMLField: {'widget': CKEditorUploadingWidget}
        }




from django.urls import path
from django.conf.urls.i18n import i18n_patterns

from seo.views import sitemap_download, sitemap_tree


app_urls = [
    path('sitemap.xml', sitemap_download)
] + i18n_patterns(
    path('sitemap/', sitemap_tree, name='sitemap-tree'),
)




from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from modeltranslation.admin import TranslationTabularInline

from model_search.models import SearchTag, SearchTagGroup, SearchQuery


class SearchTagInline(TranslationTabularInline):
    fields = ['text']
    model = SearchTag


class SearchTagGroupAdmin(admin.ModelAdmin):

    inlines = [SearchTagInline]

    list_display = ['name', 'get_latest_tag_names']

    def get_latest_tag_names(self, obj):
        return ', '.join(
            obj.tags.all().order_by('-id')[:5].values_list('text', flat=True))

    get_latest_tag_names.short_description = _('Latest tags')


class SearchQueryAdmin(admin.ModelAdmin):

    def has_add_permission(self, request):
        return False


admin.site.register(SearchTagGroup, SearchTagGroupAdmin)
admin.site.register(SearchQuery, SearchQueryAdmin)




from datetime import time

from django.forms.widgets import Select


def get_time_choices(start, end):

    choices = []

    for i in range(start, end):

        for minutes in ['00', '30']:
            time = '{}:{}'.format(str(i).zfill(2), minutes)
            choices.append((time, time), )

    time = '{}:00'.format(str(end).zfill(2))
    choices.append((time, time), )

    return choices


class TimeSelect(Select):

    def __init__(self, attrs=None, start=8, end=22):
        super().__init__(attrs, choices=get_time_choices(start, end))

    def format_value(self, value):

        if isinstance(value, time):
            value = value.strftime('%H:%M')

        return super().format_value(value)




from django.db import models
from django.utils.translation import ugettext_lazy as _


class SearchTagGroup(models.Model):

    name = models.CharField(_('Group name'), max_length=255, unique=True)

    def __unicode__(self):
        return self.name

    class Meta:
        verbose_name = _('Search tag group')
        verbose_name_plural = _('Search tag groups')


class SearchTag(models.Model):

    group = models.ForeignKey(
        SearchTagGroup, verbose_name=_('Group'), related_name='tags')

    text = models.CharField(_('Text'), max_length=255, unique=True)

    def __unicode__(self):
        return self.text

    class Meta:
        verbose_name = _('Search tag')
        verbose_name_plural = _('Search tags')


class SearchQuery(models.Model):

    url = models.URLField(_('URL'), max_length=255)

    text = models.CharField(_('Text'), max_length=255, unique=True)

    result_count = models.IntegerField(_('Result count'))

    def __unicode__(self):
        return self.text

    @classmethod
    def add(cls, url, text, result_count):
        return cls.objects.get_or_create(
            url=url, text=text, result_count=result_count)

    class Meta:
        verbose_name = _('Search query')
        verbose_name_plural = _('Search queries')




from django.shortcuts import render, redirect, Http404
from django.contrib.sitemaps.views import sitemap

from seo.models import RedirectRecord, ErrorRecord


def sitemap_download(request):
    try:
        from core.sitemaps import CommonSitemap
        return sitemap(request, {'generic': CommonSitemap})
    except ImportError:
        raise Http404()


def sitemap_tree(request):
    return render(request, 'sitemap.html')


def page_not_found(request, **kwargs):

    path = request.path

    try:
        record = RedirectRecord.objects.get(old_path=path)
        return redirect(record.new_path, permanent=True)
    except RedirectRecord.DoesNotExist:
        pass

    if not path.startswith('/static/') and not path.startswith('/media/'):
        ErrorRecord.create(request, 404)

    return render(request, '404.html')



# Generated by Django 2.0.6 on 2018-08-10 16:16

from django.db import migrations, models
import site_config.models


class Migration(migrations.Migration):

    dependencies = [
        ('site_config', '0003_auto_20171023_1207'),
    ]

    operations = [
        migrations.AddField(
            model_name='configfield',
            name='value_html',
            field=site_config.models.HTMLField(blank=True, null=True, verbose_name='HTML'),
        ),
        migrations.AlterField(
            model_name='configfield',
            name='name',
            field=models.CharField(max_length=255, unique=True, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='configfield',
            name='splitter',
            field=models.CharField(blank=True, choices=[('newline', 'New line'), (',', 'Comma'), ('.', 'Dot'), (';', 'Semicolon'), (' ', 'Tab')], help_text='Доступно тільки для типів: text, input', max_length=10, null=True, verbose_name='Splitter'),
        ),
        migrations.AlterField(
            model_name='configfield',
            name='type',
            field=models.CharField(choices=[('input', 'Input'), ('text', 'Text'), ('html', 'HTML'), ('int', 'Integer'), ('float', 'Float'), ('bool', 'True / False'), ('url', 'Url'), ('email', 'Email'), ('file', 'File'), ('image', 'Image'), ('json', 'JSON')], max_length=50, verbose_name='Type'),
        ),
        migrations.AlterField(
            model_name='configfield',
            name='value_file',
            field=models.FileField(blank=True, null=True, upload_to='site_config', verbose_name='File'),
        ),
        migrations.AlterField(
            model_name='configfield',
            name='value_image',
            field=models.ImageField(blank=True, null=True, upload_to='site_config', verbose_name='Image'),
        ),
        migrations.AlterUniqueTogether(
            name='configfield',
            unique_together=set(),
        ),
        migrations.RemoveField(
            model_name='configfield',
            name='site',
        ),
    ]




class CapSettings(object):

    @property
    def INSTALLED_APPS(self):

        apps = super().INSTALLED_APPS + [
            'cap',
            'adminplus',
            'django.contrib.admin.apps.SimpleAdminConfig'
        ]

        if 'easy_select2' not in apps:
            apps.append('easy_select2')

        return apps

    @property
    def DATE_INPUT_FORMATS(self):
        return ['%d/%m/%Y'] + super().DATE_INPUT_FORMATS


default = CapSettings



# Generated by Django 3.0.7 on 2020-06-06 22:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0005_auto_20190427_1001'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagemeta',
            name='og_image',
            field=models.CharField(blank=True, max_length=500, verbose_name='og:image'),
        ),
    ]



# Generated by Django 3.0.10 on 2020-11-19 07:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('flatpages', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='flatpage',
            name='content_en',
            field=models.TextField(blank=True, null=True, verbose_name='Content'),
        ),
        migrations.AddField(
            model_name='flatpage',
            name='content_ru',
            field=models.TextField(blank=True, null=True, verbose_name='Content'),
        ),
        migrations.AddField(
            model_name='flatpage',
            name='content_uk',
            field=models.TextField(blank=True, null=True, verbose_name='Content'),
        ),
        migrations.AddField(
            model_name='flatpage',
            name='title_en',
            field=models.CharField(max_length=200, null=True, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='flatpage',
            name='title_ru',
            field=models.CharField(max_length=200, null=True, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='flatpage',
            name='title_uk',
            field=models.CharField(max_length=200, null=True, verbose_name='Title'),
        ),
    ]




from django import template
from django.conf import settings
from django.utils.safestring import mark_safe

from cap import config

register = template.Library()


@register.filter(name='cap_conf')
def cap_conf(name, request):
    value = config.get_config(name, request)
    return mark_safe(value) if isinstance(value, str) else value


@register.filter(name='cap_body_class')
def cap_body_class(value, request):
    css_classes = []
    config_vars_to_add = ['toggle_changelist_top_actions', 'form_submit_on_right', 'layout']
    for each in config_vars_to_add:
        cap_conf_param = getattr(config.get_config(None, request), each, None)
        if cap_conf_param:
            value = each if isinstance(cap_conf_param, bool) \
                else '_'.join((each, cap_conf_param))
            css_classes.append('cap_%s' % value)
    return ' '.join(css_classes)


@register.simple_tag(takes_context=True)
def get_core_settings(context):
    if context.request.user.is_staff:
        return settings
    return {}